@@ -189,7 +189,7 @@ class Service(web.Application):
                 service=os.getenv("DD_SERVICE"),
                 env=os.getenv("DD_ENV"),
                 api_key=os.getenv("DD_API_KEY"),
-                app_key=os.getenv("DD_APP_KEY")
+                app_key=os.getenv("DD_APP_KEY"),
             )
 
         host = os.getenv('SERVICE_HOST', '0.0.0.0')
